Description: MMinte - Microbial metabolic interaction

# Welcome to MMinte!

## The least you need to know

The microbiome is an expanding field of research in the biological sciences. Its integrative approaches have mostly included 16S rDNA surveys. These surveys have been used to generate associative community network topologies, but do not assess the mechanistic basis of these associations. Here, we present MMinte a tool for assessing the microbial metabolic interactions within a microbiome network. With MMinte, users need only provide a table containing pairs of operational taxonomic units (OTUs) that will be the focus of the analysis and representative sequences for those OTUs. MMinte will then perform a series of sequential tasks to assess the kind of ecological interactions that are potentially occurring between each pair of members in the community. The final output is a network diagram representing these interactions.

MMinte is divided into six widgets with specific functions that may be used individually or sequentially. This modularity allows the user to have better control of the workflow.

## The full description

MMinte (pronounced /`minti/) is a set of widgets that allows users to explore the different kinds of pairwise interactions (positive or negative) that occur between members of a microbial community under different nutritional conditions. These interactions are predicted for the taxonomic units of interest from as little information as the 16S dRNA sequences commonly obtained in studies describing the species membership of microbial communities. Our application is composed of six widgets that run sequentially, with each widget using the output of prior widgets as its input for the analysis. While MMinte may be run as a streamlined pipeline, due to its compartmentalized nature, the user is given the ability to better control the full analysis. The user may choose to start the application at any of the six widgets, as long as the data provided has the correct structure. The user also has access to the output files of each widget. This allows the user to verify the quality of the data produced at each step of the analysis, as well as explore it with alternative tools.

The widgets that make up MMinte, and the particular analysis they perform are the following:

- Widget 1 - Using information about pairs of operational taxonomic units (OTUs) that are associated to some degree and a list of 16S rDNA sequences for the OTUs in a particular community, a file is created containing only the sequences for representative OTUs significant to the analyses.
- Widget 2 - The representative OTUs are identified and assigned a genome ID using BLAST and a local database containing the 16S rDNA sequences of species with whole genome sequences.
- Widget 3 - Metabolic models for each genome ID are reconstructed and gap filled using the ModelSEED web service and downloaded to the user's local machine.
- Widget 4 - Metabolic models of two species communities are created using COBRA Toolbox for the python computational framework (COBRApy).
- Widget 5 - Under defined nutritional conditions, the growth rates of each species in isolation and when in the presence of another species in the community are estimated. The kinds of interactions occurring between the pairs of species on the nutritional conditions are predicted. The interactions are either positive (commensalism, mutualism) or negative (parasitism, amensalism, competition).
- Widget 6 - A network is plotted with D3.js using the initial information of associations between the pairs of OTUs provided by the used, and the kinds of interactions predicted to be occurring.

## Tracking the progress of the analysis

Note that if you want to track the progress of the analysis you can consult the log files. To do this, navigate to the folder shown in the first line of output from launchMMinte. As the analysis is ongoing the "mminte_error_log.txt" file is updated. If you type "tail -f mminte_error_log.txt" in the terminal, you can see the progression. You can find more information in the README file.

## About MMinte

MMinte was developed by scientists and developers at the Center for Individualized Medicine at the Mayo Clinic and Harvard Medical School.

Please note that MMinte is still being actively developed. If you want us to let you know of updates or have suggestions, just shoot us an email.

Send an email to MMinte's awesome team!